.. _large_deformation-compare_elastic_materials:

large_deformation/compare_elastic_materials.py
==============================================

**Description**


Compare various elastic materials w.r.t. uniaxial tension/compression test.

Requires Matplotlib.


.. image:: /../doc/images/gallery/large_deformation-compare_elastic_materials-pressure_displacement.png


:download:`source code </../sfepy/examples/large_deformation/compare_elastic_materials.py>`

.. literalinclude:: /../sfepy/examples/large_deformation/compare_elastic_materials.py

